# visbeat3

This is a migration of [visbeat](http://abedavis.com/visualbeat/) from Python2 to Python3. All credits belong to the original author.

## Install

```
pip3 install -e git+https://github.com/haofanwang/visbeat3.git#egg=visbeat3
```

## Usage

```
import visbeat3 as vb
```

## Reference
```
@inproceedings{davis2018visual,
  title={Visual rhythm and beat},
  author={Davis, Abe and Agrawala, Maneesh},
  booktitle={Proceedings of the IEEE Conference on Computer Vision and Pattern Recognition Workshops},
  pages={2532--2535},
  year={2018}
}
```
